Change 14919 by ams@lustre on 2002/03/01 03:03:12

           Upgrade to Tie::File 0.13 (Win32 fixes.)

Affected files ...

.... //depot/perl/lib/Tie/File.pm#2 edit
.... //depot/perl/lib/Tie/File/01_gen.t#2 edit
.... //depot/perl/lib/Tie/File/02_fetchsize.t#2 edit
.... //depot/perl/lib/Tie/File/03_longfetch.t#2 edit
.... //depot/perl/lib/Tie/File/04_splice.t#2 edit
.... //depot/perl/lib/Tie/File/05_size.t#2 edit
.... //depot/perl/lib/Tie/File/06_fixrec.t#2 edit
.... //depot/perl/lib/Tie/File/07_rv_splice.t#2 edit
.... //depot/perl/lib/Tie/File/08_ro.t#2 edit
.... //depot/perl/lib/Tie/File/09_gen_rs.t#2 edit
.... //depot/perl/lib/Tie/File/10_splice_rs.t#2 edit
.... //depot/perl/lib/Tie/File/11_rv_splice_rs.t#2 edit
.... //depot/perl/lib/Tie/File/12_longfetch_rs.t#2 edit
.... //depot/perl/lib/Tie/File/13_size_rs.t#2 edit

Differences ...

==== //depot/perl/lib/Tie/File.pm#2 (text) ====
Index: perl/lib/Tie/File/02_fetchsize.t
--- perl/lib/Tie/File/02_fetchsize.t.~1~        Thu Feb 28 20:15:05 2002
+++ perl/lib/Tie/File/02_fetchsize.t    Thu Feb 28 20:15:05 2002
@@ -10,6 +10,7 @@
 print "ok $N\n"; $N++;
 
 open F, "> $file" or die $!;
+binmode F;
 print F $data;
 close F;
 

==== //depot/perl/lib/Tie/File/03_longfetch.t#2 (text) ====
Index: perl/lib/Tie/File/03_longfetch.t
--- perl/lib/Tie/File/03_longfetch.t.~1~        Thu Feb 28 20:15:05 2002
+++ perl/lib/Tie/File/03_longfetch.t    Thu Feb 28 20:15:05 2002
@@ -16,6 +16,7 @@
 print "ok $N\n"; $N++;
 
 open F, "> $file" or die $!;
+binmode F;
 print F $data;
 close F;
 

==== //depot/perl/lib/Tie/File/04_splice.t#2 (text) ====
Index: perl/lib/Tie/File/04_splice.t
--- perl/lib/Tie/File/04_splice.t.~1~   Thu Feb 28 20:15:05 2002
+++ perl/lib/Tie/File/04_splice.t       Thu Feb 28 20:15:05 2002
@@ -140,6 +140,7 @@
 sub init_file {
   my $data = shift;
   open F, "> $file" or die $!;
+  binmode F;
   print F $data;
   close F;
 }
@@ -151,6 +152,7 @@
   print $integrity ? "ok $N\n" : "not ok $N\n";
   $N++;
   my $open = open FH, "< $file";
+  binmode FH;
   my $a;
   { local $/; $a = <FH> }
   print (($open && $a eq $x) ? "ok $N\n" : "not ok $N\n");

==== //depot/perl/lib/Tie/File/05_size.t#2 (text) ====
Index: perl/lib/Tie/File/05_size.t
--- perl/lib/Tie/File/05_size.t.~1~     Thu Feb 28 20:15:05 2002
+++ perl/lib/Tie/File/05_size.t Thu Feb 28 20:15:05 2002
@@ -16,6 +16,7 @@
 
 # 2-3 FETCHSIZE 0-length file
 open F, "> $file" or die $!;
+binmode F;
 close F;
 $o = tie @a, 'Tie::File', $file;
 print $o ? "ok $N\n" : "not ok $N\n";
@@ -30,6 +31,7 @@
 
 # 4-5 FETCHSIZE positive-length file
 open F, "> $file" or die $!;
+binmode F;
 print F $data;
 close F;
 $o = tie @a, 'Tie::File', $file;
@@ -65,6 +67,7 @@
   my $x = shift;
   local *FH;
   my $open = open FH, "< $file";
+  binmode FH;
   my $a;
   { local $/; $a = <FH> }
   print (($open && $a eq $x) ? "ok $N\n" : "not ok $N\n");

==== //depot/perl/lib/Tie/File/06_fixrec.t#2 (text) ====
Index: perl/lib/Tie/File/06_fixrec.t
--- perl/lib/Tie/File/06_fixrec.t.~1~   Thu Feb 28 20:15:05 2002
+++ perl/lib/Tie/File/06_fixrec.t       Thu Feb 28 20:15:05 2002
@@ -23,6 +23,7 @@
   my $x = shift;
   local *FH;
   my $open = open FH, "< $file";
+  binmode FH;
   my $a;
   { local $/; $a = <FH> }
   print (($open && $a eq $x) ? "ok $N\n" : "not ok $N\n");

==== //depot/perl/lib/Tie/File/07_rv_splice.t#2 (text) ====
Index: perl/lib/Tie/File/07_rv_splice.t
--- perl/lib/Tie/File/07_rv_splice.t.~1~        Thu Feb 28 20:15:05 2002
+++ perl/lib/Tie/File/07_rv_splice.t    Thu Feb 28 20:15:05 2002
@@ -133,6 +133,7 @@
 sub init_file {
   my $data = shift;
   open F, "> $file" or die $!;
+  binmode F;
   print F $data;
   close F;
 }

==== //depot/perl/lib/Tie/File/08_ro.t#2 (text) ====
Index: perl/lib/Tie/File/08_ro.t
--- perl/lib/Tie/File/08_ro.t.~1~       Thu Feb 28 20:15:05 2002
+++ perl/lib/Tie/File/08_ro.t   Thu Feb 28 20:15:05 2002
@@ -30,6 +30,7 @@
 sub init_file {
   my $data = shift;
   open F, "> $file" or die $!;
+  binmode F;
   print F $data;
   close F;
 }

==== //depot/perl/lib/Tie/File/09_gen_rs.t#2 (text) ====
Index: perl/lib/Tie/File/09_gen_rs.t
--- perl/lib/Tie/File/09_gen_rs.t.~1~   Thu Feb 28 20:15:05 2002
+++ perl/lib/Tie/File/09_gen_rs.t       Thu Feb 28 20:15:05 2002
@@ -70,6 +70,7 @@
   my $x = join 'blah', @c, '';
   local *FH;
   my $open = open FH, "< $file";
+  binmode FH;
   my $a;
   { local $/; $a = <FH> }
   print (($open && $a eq $x) ? "ok $N\n" : "not ok $N # file @c\n");

==== //depot/perl/lib/Tie/File/10_splice_rs.t#2 (text) ====
Index: perl/lib/Tie/File/10_splice_rs.t
--- perl/lib/Tie/File/10_splice_rs.t.~1~        Thu Feb 28 20:15:05 2002
+++ perl/lib/Tie/File/10_splice_rs.t    Thu Feb 28 20:15:05 2002
@@ -139,6 +139,7 @@
 sub init_file {
   my $data = shift;
   open F, "> $file" or die $!;
+  binmode F;
   print F $data;
   close F;
 }

==== //depot/perl/lib/Tie/File/11_rv_splice_rs.t#2 (text) ====
Index: perl/lib/Tie/File/11_rv_splice_rs.t
--- perl/lib/Tie/File/11_rv_splice_rs.t.~1~     Thu Feb 28 20:15:05 2002
+++ perl/lib/Tie/File/11_rv_splice_rs.t Thu Feb 28 20:15:05 2002
@@ -133,6 +133,7 @@
 sub init_file {
   my $data = shift;
   open F, "> $file" or die $!;
+  binmode F;
   print F $data;
   close F;
 }

==== //depot/perl/lib/Tie/File/12_longfetch_rs.t#2 (text) ====
Index: perl/lib/Tie/File/12_longfetch_rs.t
--- perl/lib/Tie/File/12_longfetch_rs.t.~1~     Thu Feb 28 20:15:05 2002
+++ perl/lib/Tie/File/12_longfetch_rs.t Thu Feb 28 20:15:05 2002
@@ -16,6 +16,7 @@
 print "ok $N\n"; $N++;
 
 open F, "> $file" or die $!;
+binmode F;
 print F $data;
 close F;
 

==== //depot/perl/lib/Tie/File/13_size_rs.t#2 (text) ====

End of Patch.

Reply via email to
Index: perl/lib/Tie/File.pm
--- perl/lib/Tie/File.pm.~1~    Thu Feb 28 20:15:05 2002
+++ perl/lib/Tie/File.pm        Thu Feb 28 20:15:05 2002
@@ -5,7 +5,7 @@
 use Fcntl 'O_CREAT', 'O_RDWR';
 require 5.005;
 
-$VERSION = "0.12";
+$VERSION = "0.13";
 
 # Idea: The object will always contain an array of byte offsets
 # this will be filled in as is necessary and convenient.
@@ -434,6 +434,7 @@
   my $good = 1; 
   local *F;
   open F, $file or die "Couldn't open file $file: $!";
+  binmode F;
   local $/ = $self->{recsep};
   unless ($self->{offsets}[0] == 0) {
     $warn && print STDERR "# rec 0: offset <$self->{offsets}[0]> s/b 0!\n";
@@ -498,7 +499,7 @@
 
 =head1 SYNOPSIS
 
        # This file documents Tie::File version 0.12
 
        tie @array, 'Tie::File', filename or die ...;
 
@@ -692,7 +693,7 @@
 
 =head1 LICENSE
 
-C<Tie::File> version 0.12 is copyright (C) 2002 Mark Jason Dominus.
+C<Tie::File> version 0.13 is copyright (C) 2002 Mark Jason Dominus.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -717,7 +718,7 @@
 
 =head1 WARRANTY
 
-C<Tie::File> version 0.12 comes with ABSOLUTELY NO WARRANTY.
+C<Tie::File> version 0.13 comes with ABSOLUTELY NO WARRANTY.
 For details, see the license.
 
 =head1 TODO
@@ -498,7 +499,7 @@
 =head1 SYNOPSIS
 
-       # This file documents Tie::File version 0.12
+       # This file documents Tie::File version 0.13
 
        tie @array, 'Tie::File', filename or die ...;

==== //depot/perl/lib/Tie/File/01_gen.t#2 (text) ====
==== //depot/perl/lib/Tie/File/02_fetchsize.t#2 (text) ====